@@ -43,6 +43,24 @@ factor_layer = function(id, levels, in_memory = FALSE) {
   list(id = id, type = "factor", levels = levels, in_memory = in_memory)
 }
 
+#' @title Weights Layer Generator
+#'
+#' @description
+#' Generates a weights layer when passed to [generate_stack()].
+#'
+#' @param id (`character(1)`)\cr
+#'   Layer id.
+#' @param in_memory (`logical(1)`)\cr
+#'   If `FALSE` (default), layer is written to disk.
+#'
+#' @keywords internal
+#' @export
+weights_layer = function(id, in_memory = FALSE) {
+  assert_string(id)
+  assert_flag(in_memory)
+  list(id = id, type = "weights", in_memory = in_memory)
+}
+
 #' @title Generate Raster Stack
 #'
 #' @description
@@ -80,6 +98,7 @@ generate_stack = function(layers, layer_size = NULL, dimension = NULL, multi_lay
     if (layer$type == "numeric") {
       data = matrix(c(stats::rnorm(floor(dimension^2 / 2), 0, 1), stats::rnorm(ceiling(dimension^2 / 2), 1, 1)), nrow = dimension)
       ras = rast(data)
+      terra::crs(ras) = "EPSG:4326"
       if (!layer$in_memory && !multi_layer_file) {
         filename = tempfile(fileext = ".tif")
         writeRaster(ras, filename)
@@ -89,6 +108,7 @@ generate_stack = function(layers, layer_size = NULL, dimension = NULL, multi_lay
     } else if (layer$type == "factor") {
       data = matrix(rep(seq_along(layer$levels), each = floor(dimension^2 / length(layer$levels)), length.out = dimension^2), nrow = dimension)
       ras = rast(data)
+      terra::crs(ras) = "EPSG:4326"
       ras = terra::categories(ras, layer = 1, data.table(ID = seq_along(layer$levels), category = layer$levels))
       if (!layer$in_memory && !multi_layer_file) {
         filename = tempfile(fileext = ".tif")
@@ -96,6 +116,16 @@ generate_stack = function(layers, layer_size = NULL, dimension = NULL, multi_lay
         ras = rast(filename)
       }
       ras
+    } else if (layer$type == "weights") {
+      data = matrix(runif(dimension^2, 0, 1), nrow = dimension)
+      ras = rast(data)
+      terra::crs(ras) = "EPSG:4326"
+      if (!layer$in_memory && !multi_layer_file) {
+        filename = tempfile(fileext = ".tif")
+        writeRaster(ras, filename)
+        ras = rast(filename)
+      }
+      ras
     }
   })
 
